@@ -5,7 +5,7 @@ int main(array<System::String ^> ^/*args*/)
 {
   try {
     // Print waypoints between JFK and SIN
-    Rhumb^ rhumb = gcnew Rhumb(Constants::WGS84::MajorRadius, Constants::WGS84::Flattening, true);
+    Rhumb^ rhumb = gcnew Rhumb(Constants::WGS84::EquatorialRadius, Constants::WGS84::Flattening, true);
     // Alternatively: const Rhumb& rhumb = Rhumb::WGS84();
     double
       lat1 = 40.640, lon1 = -73.779, // JFK
