@@ -2,7 +2,7 @@
  * \file Math.hpp
  * \brief Header for GeographicLib::Math class
  *
- * Copyright (c) Charles Karney (2008-2017) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2008-2019) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  **********************************************************************/
@@ -63,12 +63,8 @@
 
 #if GEOGRAPHICLIB_PRECISION == 4
 #include <boost/version.hpp>
-#if BOOST_VERSION >= 105600
-#include <boost/cstdfloat.hpp>
-#endif
 #include <boost/multiprecision/float128.hpp>
 #include <boost/math/special_functions.hpp>
-__float128 fmaq(__float128, __float128, __float128);
 #elif GEOGRAPHICLIB_PRECISION == 5
 #include <mpreal.h>
 #endif
@@ -101,11 +97,7 @@ namespace GeographicLib {
    **********************************************************************/
   class GEOGRAPHICLIB_EXPORT Math {
   private:
-    void dummy() {
-      GEOGRAPHICLIB_STATIC_ASSERT(GEOGRAPHICLIB_PRECISION >= 1 &&
-                                  GEOGRAPHICLIB_PRECISION <= 5,
-                                  "Bad value of precision");
-    }
+    void dummy();               // Static check for GEOGRAPHICLIB_PRECISION
     Math();                     // Disable constructor
   public:
 
@@ -142,13 +134,7 @@ namespace GeographicLib {
     /**
      * @return the number of bits of precision in a real number.
      **********************************************************************/
-    static int digits() {
-#if GEOGRAPHICLIB_PRECISION != 5
-      return std::numeric_limits<real>::digits;
-#else
-      return std::numeric_limits<real>::digits();
-#endif
-    }
+    static int digits();
 
     /**
      * Set the binary precision of a real number.
@@ -160,35 +146,18 @@ namespace GeographicLib {
      * Utility::set_digits for caveats about when this routine should be
      * called.
      **********************************************************************/
-    static int set_digits(int ndigits) {
-#if GEOGRAPHICLIB_PRECISION != 5
-      (void)ndigits;
-#else
-      mpfr::mpreal::set_default_prec(ndigits >= 2 ? ndigits : 2);
-#endif
-      return digits();
-    }
+    static int set_digits(int ndigits);
 
     /**
      * @return the number of decimal digits of precision in a real number.
      **********************************************************************/
-    static int digits10() {
-#if GEOGRAPHICLIB_PRECISION != 5
-      return std::numeric_limits<real>::digits10;
-#else
-      return std::numeric_limits<real>::digits10();
-#endif
-    }
+    static int digits10();
 
     /**
      * Number of additional decimal digits of precision for real relative to
      * double (0 for float).
      **********************************************************************/
-    static int extra_digits() {
-      return
-        digits10() > std::numeric_limits<double>::digits10 ?
-        digits10() - std::numeric_limits<double>::digits10 : 0;
-    }
+    static int extra_digits();
 
     /**
      * true if the machine is big-endian.
@@ -240,20 +209,7 @@ namespace GeographicLib {
      * @param[in] y
      * @return sqrt(<i>x</i><sup>2</sup> + <i>y</i><sup>2</sup>).
      **********************************************************************/
-    template<typename T> static T hypot(T x, T y) {
-#if GEOGRAPHICLIB_CXX11_MATH
-      using std::hypot; return hypot(x, y);
-#else
-      using std::abs; using std::sqrt;
-      x = abs(x); y = abs(y);
-      if (x < y) std::swap(x, y); // Now x >= y >= 0
-      y /= (x ? x : 1);
-      return x * sqrt(1 + y * y);
-      // For an alternative (square-root free) method see
-      // C. Moler and D. Morrision (1983) https://doi.org/10.1147/rd.276.0577
-      // and A. A. Dubrulle (1983) https://doi.org/10.1147/rd.276.0582
-#endif
-    }
+    template<typename T> static T hypot(T x, T y);
 
     /**
      * exp(\e x) &minus; 1 accurate near \e x = 0.
@@ -262,21 +218,7 @@ namespace GeographicLib {
      * @param[in] x
      * @return exp(\e x) &minus; 1.
      **********************************************************************/
-    template<typename T> static T expm1(T x) {
-#if GEOGRAPHICLIB_CXX11_MATH
-      using std::expm1; return expm1(x);
-#else
-      using std::exp; using std::abs; using std::log;
-      GEOGRAPHICLIB_VOLATILE T
-        y = exp(x),
-        z = y - 1;
-      // The reasoning here is similar to that for log1p.  The expression
-      // mathematically reduces to exp(x) - 1, and the factor z/log(y) = (y -
-      // 1)/log(y) is a slowly varying quantity near y = 1 and is accurately
-      // computed.
-      return abs(x) > 1 ? z : (z == 0 ? x : x * z / log(y));
-#endif
-    }
+    template<typename T> static T expm1(T x);
 
     /**
      * log(1 + \e x) accurate near \e x = 0.
@@ -285,21 +227,7 @@ namespace GeographicLib {
      * @param[in] x
      * @return log(1 + \e x).
      **********************************************************************/
-    template<typename T> static T log1p(T x) {
-#if GEOGRAPHICLIB_CXX11_MATH
-      using std::log1p; return log1p(x);
-#else
-      using std::log;
-      GEOGRAPHICLIB_VOLATILE T
-        y = 1 + x,
-        z = y - 1;
-      // Here's the explanation for this magic: y = 1 + z, exactly, and z
-      // approx x, thus log(y)/z (which is nearly constant near z = 0) returns
-      // a good approximation to the true log(1 + x)/x.  The multiplication x *
-      // (log(y)/z) introduces little additional error.
-      return z == 0 ? x : x * log(y) / z;
-#endif
-    }
+    template<typename T> static T log1p(T x);
 
     /**
      * The inverse hyperbolic sine function.
@@ -308,15 +236,7 @@ namespace GeographicLib {
      * @param[in] x
      * @return asinh(\e x).
      **********************************************************************/
-    template<typename T> static T asinh(T x) {
-#if GEOGRAPHICLIB_CXX11_MATH
-      using std::asinh; return asinh(x);
-#else
-      using std::abs; T y = abs(x); // Enforce odd parity
-      y = log1p(y * (1 + y/(hypot(T(1), y) + 1)));
-      return x < 0 ? -y : y;
-#endif
-    }
+    template<typename T> static T asinh(T x);
 
     /**
      * The inverse hyperbolic tangent function.
@@ -325,15 +245,20 @@ namespace GeographicLib {
      * @param[in] x
      * @return atanh(\e x).
      **********************************************************************/
-    template<typename T> static T atanh(T x) {
-#if GEOGRAPHICLIB_CXX11_MATH
-      using std::atanh; return atanh(x);
-#else
-      using std::abs; T y = abs(x); // Enforce odd parity
-      y = log1p(2 * y/(1 - y))/2;
-      return x < 0 ? -y : y;
-#endif
-    }
+    template<typename T> static T atanh(T x);
+
+    /**
+     * Copy the sign.
+     *
+     * @tparam T the type of the argument.
+     * @param[in] x gives the magitude of the result.
+     * @param[in] y gives the sign of the result.
+     * @return value with the magnitude of \e x and with the sign of \e y.
+     *
+     * This routine correctly handles the case \e y = &minus;0, returning
+     * &minus|<i>x</i>|.
+     **********************************************************************/
+    template<typename T> static T copysign(T x, T y);
 
     /**
      * The cube root function.
@@ -342,15 +267,49 @@ namespace GeographicLib {
      * @param[in] x
      * @return the real cube root of \e x.
      **********************************************************************/
-    template<typename T> static T cbrt(T x) {
-#if GEOGRAPHICLIB_CXX11_MATH
-      using std::cbrt; return cbrt(x);
-#else
-      using std::abs; using std::pow;
-      T y = pow(abs(x), 1/T(3)); // Return the real cube root
-      return x < 0 ? -y : y;
-#endif
-    }
+    template<typename T> static T cbrt(T x);
+
+    /**
+     * The remainder function.
+     *
+     * @tparam T the type of the arguments and the returned value.
+     * @param[in] x
+     * @param[in] y
+     * @return the remainder of \e x/\e y in the range [&minus;\e y/2, \e y/2].
+     **********************************************************************/
+    template<typename T> static T remainder(T x, T y);
+
+    /**
+     * The remquo function.
+     *
+     * @tparam T the type of the arguments and the returned value.
+     * @param[in] x
+     * @param[in] y
+     * @param[out] n the low 3 bits of the quotient
+     * @return the remainder of \e x/\e y in the range [&minus;\e y/2, \e y/2].
+     **********************************************************************/
+    template<typename T> static T remquo(T x, T y, int* n);
+
+    /**
+     * The round function.
+     *
+     * @tparam T the type of the argument and the returned value.
+     * @param[in] x
+     * @return \e x round to the nearest integer (ties round away from 0).
+     **********************************************************************/
+    template<typename T> static T round(T x);
+
+    /**
+     * The lround function.
+     *
+     * @tparam T the type of the argument.
+     * @param[in] x
+     * @return \e x round to the nearest integer as a long int (ties round away
+     *   from 0).
+     *
+     * If the result does not fit in a long int, the return value is undefined.
+     **********************************************************************/
+    template<typename T> static long lround(T x);
 
     /**
      * Fused multiply and add.
@@ -366,13 +325,7 @@ namespace GeographicLib {
      * made to improve on the result of a rounded multiplication followed by a
      * rounded addition.
      **********************************************************************/
-    template<typename T> static T fma(T x, T y, T z) {
-#if GEOGRAPHICLIB_CXX11_MATH
-      using std::fma; return fma(x, y, z);
-#else
-      return x * y + z;
-#endif
-    }
+    template<typename T> static T fma(T x, T y, T z);
 
     /**
      * Normalize a two-vector.
@@ -396,17 +349,7 @@ namespace GeographicLib {
      * See D. E. Knuth, TAOCP, Vol 2, 4.2.2, Theorem B.  (Note that \e t can be
      * the same as one of the first two arguments.)
      **********************************************************************/
-    template<typename T> static T sum(T u, T v, T& t) {
-      GEOGRAPHICLIB_VOLATILE T s = u + v;
-      GEOGRAPHICLIB_VOLATILE T up = s - v;
-      GEOGRAPHICLIB_VOLATILE T vpp = s - up;
-      up -= u;
-      vpp -= v;
-      t = -(up + vpp);
-      // u + v =       s      + t
-      //       = round(u + v) + t
-      return s;
-    }
+    template<typename T> static T sum(T u, T v, T& t);
 
     /**
      * Evaluate a polynomial.
@@ -433,27 +376,12 @@ namespace GeographicLib {
      *
      * @tparam T the type of the argument and returned value.
      * @param[in] x the angle in degrees.
-     * @return the angle reduced to the range([&minus;180&deg;, 180&deg;].
+     * @return the angle reduced to the range (&minus;180&deg;, 180&deg;].
      *
      * The range of \e x is unrestricted.
      **********************************************************************/
     template<typename T> static T AngNormalize(T x) {
-#if GEOGRAPHICLIB_CXX11_MATH && GEOGRAPHICLIB_PRECISION != 4
-      using std::remainder;
       x = remainder(x, T(360)); return x != -180 ? x : 180;
-#else
-      using std::fmod;
-      T y = fmod(x, T(360));
-#if defined(_MSC_VER) && _MSC_VER < 1900
-      // Before version 14 (2015), Visual Studio had problems dealing
-      // with -0.0.  Specifically
-      //   VC 10,11,12 and 32-bit compile: fmod(-0.0, 360.0) -> +0.0
-      // sincosd has a similar fix.
-      // python 2.7 on Windows 32-bit machines has the same problem.
-      if (x == 0) y = x;
-#endif
-      return y <= -180 ? y + 360 : (y <= 180 ? y : y - 360);
-#endif
     }
 
     /**
@@ -484,13 +412,8 @@ namespace GeographicLib {
      * &le; 0.
      **********************************************************************/
     template<typename T> static T AngDiff(T x, T y, T& e) {
-#if GEOGRAPHICLIB_CXX11_MATH && GEOGRAPHICLIB_PRECISION != 4
-      using std::remainder;
       T t, d = AngNormalize(sum(remainder(-x, T(360)),
                                 remainder( y, T(360)), t));
-#else
-      T t, d = AngNormalize(sum(AngNormalize(-x), AngNormalize(y), t));
-#endif
       // Here y - x = d + t (mod 360), exactly, where d is in (-180,180] and
       // abs(t) <= eps (eps = 2^-45 for doubles).  The only case where the
       // addition of t takes the result outside the range (-180,180] is d = 180
@@ -524,23 +447,15 @@ namespace GeographicLib {
      * @param[in] x
      * @return the coarsened value.
      *
-     * The makes the smallest gap in \e x = 1/16 - nextafter(1/16, 0) =
+     * The makes the smallest gap in \e x = 1/16 &minus; nextafter(1/16, 0) =
      * 1/2<sup>57</sup> for reals = 0.7 pm on the earth if \e x is an angle in
      * degrees.  (This is about 1000 times more resolution than we get with
      * angles around 90&deg;.)  We use this to avoid having to deal with near
      * singular cases when \e x is non-zero but tiny (e.g.,
-     * 10<sup>&minus;200</sup>).  This converts -0 to +0; however tiny negative
-     * numbers get converted to -0.
+     * 10<sup>&minus;200</sup>).  This converts &minus;0 to +0; however tiny
+     * negative numbers get converted to &minus;0.
      **********************************************************************/
-    template<typename T> static T AngRound(T x) {
-      using std::abs;
-      static const T z = 1/T(16);
-      if (x == 0) return 0;
-      GEOGRAPHICLIB_VOLATILE T y = abs(x);
-      // The compiler mustn't "simplify" z - (z - y) to y
-      y = y < z ? z - (z - y) : y;
-      return x < 0 ? -y : y;
-    }
+    template<typename T> static T AngRound(T x);
 
     /**
      * Evaluate the sine and cosine function with the argument in degrees
@@ -555,49 +470,7 @@ namespace GeographicLib {
      * If x = &minus;0, then \e sinx = &minus;0; this is the only case where
      * &minus;0 is returned.
      **********************************************************************/
-    template<typename T> static void sincosd(T x, T& sinx, T& cosx) {
-      // In order to minimize round-off errors, this function exactly reduces
-      // the argument to the range [-45, 45] before converting it to radians.
-      using std::sin; using std::cos;
-      T r; int q;
-#if GEOGRAPHICLIB_CXX11_MATH && GEOGRAPHICLIB_PRECISION <= 3 && \
-  !defined(__GNUC__)
-      // Disable for gcc because of bug in glibc version < 2.22, see
-      //   https://sourceware.org/bugzilla/show_bug.cgi?id=17569
-      // Once this fix is widely deployed, should insert a runtime test for the
-      // glibc version number.  For example
-      //   #include <gnu/libc-version.h>
-      //   std::string version(gnu_get_libc_version()); => "2.22"
-      using std::remquo;
-      r = remquo(x, T(90), &q);
-#else
-      using std::fmod; using std::floor;
-      r = fmod(x, T(360));
-      q = int(floor(r / 90 + T(0.5)));
-      r -= 90 * q;
-#endif
-      // now abs(r) <= 45
-      r *= degree();
-      // Possibly could call the gnu extension sincos
-      T s = sin(r), c = cos(r);
-#if defined(_MSC_VER) && _MSC_VER < 1900
-      // Before version 14 (2015), Visual Studio had problems dealing
-      // with -0.0.  Specifically
-      //   VC 10,11,12 and 32-bit compile: fmod(-0.0, 360.0) -> +0.0
-      //   VC 12       and 64-bit compile:  sin(-0.0)        -> +0.0
-      // AngNormalize has a similar fix.
-      // python 2.7 on Windows 32-bit machines has the same problem.
-      if (x == 0) s = x;
-#endif
-      switch (unsigned(q) & 3U) {
-      case 0U: sinx =  s; cosx =  c; break;
-      case 1U: sinx =  c; cosx = -s; break;
-      case 2U: sinx = -s; cosx = -c; break;
-      default: sinx = -c; cosx =  s; break; // case 3U
-      }
-      // Set sign of 0 results.  -0 only produced for sin(-0)
-      if (x != 0) { sinx += T(0); cosx += T(0); }
-    }
+    template<typename T> static void sincosd(T x, T& sinx, T& cosx);
 
     /**
      * Evaluate the sine function with the argument in degrees
@@ -606,28 +479,7 @@ namespace GeographicLib {
      * @param[in] x in degrees.
      * @return sin(<i>x</i>).
      **********************************************************************/
-    template<typename T> static T sind(T x) {
-      // See sincosd
-      using std::sin; using std::cos;
-      T r; int q;
-#if GEOGRAPHICLIB_CXX11_MATH && GEOGRAPHICLIB_PRECISION <= 3 && \
-  !defined(__GNUC__)
-      using std::remquo;
-      r = remquo(x, T(90), &q);
-#else
-      using std::fmod; using std::floor;
-      r = fmod(x, T(360));
-      q = int(floor(r / 90 + T(0.5)));
-      r -= 90 * q;
-#endif
-      // now abs(r) <= 45
-      r *= degree();
-      unsigned p = unsigned(q);
-      r = p & 1U ? cos(r) : sin(r);
-      if (p & 2U) r = -r;
-      if (x != 0) r += T(0);
-      return r;
-    }
+    template<typename T> static T sind(T x);
 
     /**
      * Evaluate the cosine function with the argument in degrees
@@ -636,27 +488,7 @@ namespace GeographicLib {
      * @param[in] x in degrees.
      * @return cos(<i>x</i>).
      **********************************************************************/
-    template<typename T> static T cosd(T x) {
-      // See sincosd
-      using std::sin; using std::cos;
-      T r; int q;
-#if GEOGRAPHICLIB_CXX11_MATH && GEOGRAPHICLIB_PRECISION <= 3 && \
-  !defined(__GNUC__)
-      using std::remquo;
-      r = remquo(x, T(90), &q);
-#else
-      using std::fmod; using std::floor;
-      r = fmod(x, T(360));
-      q = int(floor(r / 90 + T(0.5)));
-      r -= 90 * q;
-#endif
-      // now abs(r) <= 45
-      r *= degree();
-      unsigned p = unsigned(q + 1);
-      r = p & 1U ? cos(r) : sin(r);
-      if (p & 2U) r = -r;
-      return T(0) + r;
-    }
+    template<typename T> static T cosd(T x);
 
     /**
      * Evaluate the tangent function with the argument in degrees
@@ -668,12 +500,7 @@ namespace GeographicLib {
      * If \e x = &plusmn;90&deg;, then a suitably large (but finite) value is
      * returned.
      **********************************************************************/
-    template<typename T> static T tand(T x) {
-      static const T overflow = 1 / sq(std::numeric_limits<T>::epsilon());
-      T s, c;
-      sincosd(x, s, c);
-      return c != 0 ? s / c : (s < 0 ? -overflow : overflow);
-    }
+    template<typename T> static T tand(T x);
 
     /**
      * Evaluate the atan2 function with the result in degrees
@@ -688,30 +515,7 @@ namespace GeographicLib {
      * &minus;1) = &minus;180&deg;, for &epsilon; positive and tiny;
      * atan2d(&plusmn;0, +1) = &plusmn;0&deg;.
      **********************************************************************/
-    template<typename T> static T atan2d(T y, T x) {
-      // In order to minimize round-off errors, this function rearranges the
-      // arguments so that result of atan2 is in the range [-pi/4, pi/4] before
-      // converting it to degrees and mapping the result to the correct
-      // quadrant.
-      using std::atan2; using std::abs;
-      int q = 0;
-      if (abs(y) > abs(x)) { std::swap(x, y); q = 2; }
-      if (x < 0) { x = -x; ++q; }
-      // here x >= 0 and x >= abs(y), so angle is in [-pi/4, pi/4]
-      T ang = atan2(y, x) / degree();
-      switch (q) {
-        // Note that atan2d(-0.0, 1.0) will return -0.  However, we expect that
-        // atan2d will not be called with y = -0.  If need be, include
-        //
-        //   case 0: ang = 0 + ang; break;
-        //
-        // and handle mpfr as in AngRound.
-      case 1: ang = (y >= 0 ? 180 : -180) - ang; break;
-      case 2: ang =  90 - ang; break;
-      case 3: ang = -90 + ang; break;
-      }
-      return ang;
-    }
+    template<typename T> static T atan2d(T y, T x);
 
     /**
      * Evaluate the atan function with the result in degrees
@@ -720,8 +524,7 @@ namespace GeographicLib {
      * @param[in] x
      * @return atan(<i>x</i>) in degrees.
      **********************************************************************/
-    template<typename T> static T atand(T x)
-    { return atan2d(x, T(1)); }
+   template<typename T> static T atand(T x);
 
     /**
      * Evaluate <i>e</i> atanh(<i>e x</i>)
@@ -737,27 +540,6 @@ namespace GeographicLib {
      **********************************************************************/
     template<typename T> static T eatanhe(T x, T es);
 
-    /**
-     * Copy the sign.
-     *
-     * @tparam T the type of the argument.
-     * @param[in] x gives the magitude of the result.
-     * @param[in] y gives the sign of the result.
-     * @return value with the magnitude of \e x and with the sign of \e y.
-     *
-     * This routine correctly handles the case \e y = &minus;0, returning
-     * &minus|<i>x</i>|.
-     **********************************************************************/
-    template<typename T> static T copysign(T x, T y) {
-#if GEOGRAPHICLIB_CXX11_MATH
-      using std::copysign; return copysign(x, y);
-#else
-      using std::abs;
-      // NaN counts as positive
-      return abs(x) * (y < 0 || (y == 0 && 1/y < 0) ? -1 : 1);
-#endif
-    }
-
     /**
      * tan&chi; in terms of tan&phi;
      *
@@ -803,23 +585,7 @@ namespace GeographicLib {
      * @param[in] x
      * @return true if number is finite, false if NaN or infinite.
      **********************************************************************/
-    template<typename T> static bool isfinite(T x) {
-#if GEOGRAPHICLIB_CXX11_MATH
-      using std::isfinite; return isfinite(x);
-#else
-      using std::abs;
-#if defined(_MSC_VER)
-      return abs(x) <= (std::numeric_limits<T>::max)();
-#else
-      // There's a problem using MPFR C++ 3.6.3 and g++ -std=c++14 (reported on
-      // 2015-05-04) with the parens around std::numeric_limits<T>::max.  Of
-      // course, these parens are only needed to deal with Windows stupidly
-      // defining max as a macro.  So don't insert the parens on non-Windows
-      // platforms.
-      return abs(x) <= std::numeric_limits<T>::max();
-#endif
-#endif
-    }
+    template<typename T> static bool isfinite(T x);
 
     /**
      * The NaN (not a number)
@@ -827,17 +593,8 @@ namespace GeographicLib {
      * @tparam T the type of the returned value.
      * @return NaN if available, otherwise return the max real of type T.
      **********************************************************************/
-    template<typename T> static T NaN() {
-#if defined(_MSC_VER)
-      return std::numeric_limits<T>::has_quiet_NaN ?
-        std::numeric_limits<T>::quiet_NaN() :
-        (std::numeric_limits<T>::max)();
-#else
-      return std::numeric_limits<T>::has_quiet_NaN ?
-        std::numeric_limits<T>::quiet_NaN() :
-        std::numeric_limits<T>::max();
-#endif
-    }
+    template<typename T> static T NaN();
+
     /**
      * A synonym for NaN<real>().
      **********************************************************************/
@@ -850,13 +607,7 @@ namespace GeographicLib {
      * @param[in] x
      * @return true if argument is a NaN.
      **********************************************************************/
-    template<typename T> static bool isnan(T x) {
-#if GEOGRAPHICLIB_CXX11_MATH
-      using std::isnan; return isnan(x);
-#else
-      return x != x;
-#endif
-    }
+    template<typename T> static bool isnan(T x);
 
     /**
      * Infinity
@@ -864,17 +615,8 @@ namespace GeographicLib {
      * @tparam T the type of the returned value.
      * @return infinity if available, otherwise return the max real.
      **********************************************************************/
-    template<typename T> static T infinity() {
-#if defined(_MSC_VER)
-      return std::numeric_limits<T>::has_infinity ?
-        std::numeric_limits<T>::infinity() :
-        (std::numeric_limits<T>::max)();
-#else
-      return std::numeric_limits<T>::has_infinity ?
-        std::numeric_limits<T>::infinity() :
-        std::numeric_limits<T>::max();
-#endif
-    }
+    template<typename T> static T infinity();
+
     /**
      * A synonym for infinity<real>().
      **********************************************************************/
@@ -898,46 +640,6 @@ namespace GeographicLib {
       return b.r;
     }
 
-#if GEOGRAPHICLIB_PRECISION == 4
-    typedef boost::math::policies::policy
-      < boost::math::policies::domain_error
-        <boost::math::policies::errno_on_error>,
-        boost::math::policies::pole_error
-        <boost::math::policies::errno_on_error>,
-        boost::math::policies::overflow_error
-        <boost::math::policies::errno_on_error>,
-        boost::math::policies::evaluation_error
-        <boost::math::policies::errno_on_error> >
-      boost_special_functions_policy;
-
-    static real hypot(real x, real y)
-    { return boost::math::hypot(x, y, boost_special_functions_policy()); }
-
-    static real expm1(real x)
-    { return boost::math::expm1(x, boost_special_functions_policy()); }
-
-    static real log1p(real x)
-    { return boost::math::log1p(x, boost_special_functions_policy()); }
-
-    static real asinh(real x)
-    { return boost::math::asinh(x, boost_special_functions_policy()); }
-
-    static real atanh(real x)
-    { return boost::math::atanh(x, boost_special_functions_policy()); }
-
-    static real cbrt(real x)
-    { return boost::math::cbrt(x, boost_special_functions_policy()); }
-
-    static real fma(real x, real y, real z)
-    { return fmaq(__float128(x), __float128(y), __float128(z)); }
-
-    static real copysign(real x, real y)
-    { return boost::math::copysign(x, y); }
-
-    static bool isnan(real x) { return boost::math::isnan(x); }
-
-    static bool isfinite(real x) { return boost::math::isfinite(x); }
-#endif
   };
 
 } // namespace GeographicLib
