@@ -1,7 +1,7 @@
 /**
  * Implementation of the net.sf.geographiclib.GeodesicLine class
  *
- * Copyright (c) Charles Karney (2013-2017) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2013-2019) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  **********************************************************************/
@@ -211,9 +211,9 @@ public class GeodesicLine {
 
     // Evaluate alp0 from sin(alp1) * cos(bet1) = sin(alp0),
     _salp0 = _salp1 * cbet1; // alp0 in [0, pi/2 - |bet1|]
-    // Alt: calp0 = hypot(sbet1, calp1 * cbet1).  The following
+    // Alt: calp0 = Math.hypot(sbet1, calp1 * cbet1).  The following
     // is slightly better (consider the case salp1 = 0).
-    _calp0 = GeoMath.hypot(_calp1, _salp1 * sbet1);
+    _calp0 = Math.hypot(_calp1, _salp1 * sbet1);
     // Evaluate sig with tan(bet1) = tan(sig1) * cos(alp1).
     // sig = 0 is nearest northward crossing of equator.
     // With bet1 = 0, alp1 = pi/2, we have sig1 = 0 (equatorial line).
@@ -504,8 +504,8 @@ public class GeodesicLine {
     }
     // sin(bet2) = cos(alp0) * sin(sig2)
     sbet2 = _calp0 * ssig2;
-    // Alt: cbet2 = hypot(csig2, salp0 * ssig2);
-    cbet2 = GeoMath.hypot(_salp0, _calp0 * csig2);
+    // Alt: cbet2 = Math.hypot(csig2, salp0 * ssig2);
+    cbet2 = Math.hypot(_salp0, _calp0 * csig2);
     if (cbet2 == 0)
       // I.e., salp0 = 0, csig2 = 0.  Break the degeneracy in this case
       cbet2 = csig2 = Geodesic.tiny_;
@@ -518,7 +518,7 @@ public class GeodesicLine {
     if ((outmask & GeodesicMask.LONGITUDE) != 0) {
       // tan(omg2) = sin(alp0) * tan(sig2)
       double somg2 = _salp0 * ssig2, comg2 = csig2, // No need to normalize
-        E = GeoMath.copysign(1, _salp0);            // east or west going?
+        E = Math.copySign(1, _salp0);               // east or west going?
       // omg12 = omg2 - omg1
       double omg12 = ((outmask & GeodesicMask.LONG_UNROLL) != 0)
         ? E * (sig12
@@ -697,7 +697,7 @@ public class GeodesicLine {
    * @return <i>a</i> the equatorial radius of the ellipsoid (meters).  This is
    *   the value inherited from the Geodesic object used in the constructor.
    **********************************************************************/
-  public double MajorRadius()
+  public double EquatorialRadius()
   { return Init() ? _a : Double.NaN; }
 
   /**
@@ -743,4 +743,10 @@ public class GeodesicLine {
    **********************************************************************/
   public double Arc() { return GenDistance(true); }
 
+  /**
+   * @deprecated An old name for {@link #EquatorialRadius()}.
+   * @return <i>a</i> the equatorial radius of the ellipsoid (meters).
+   **********************************************************************/
+  // @Deprecated
+  public double MajorRadius() { return EquatorialRadius(); }
 }
