@@ -107,12 +107,12 @@
  * twice about restructuring the internals of the C code since this may make
  * porting fixes from the C++ code more difficult.
  *
- * Copyright (c) Charles Karney (2012-2017) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2012-2019) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  *
  * This library was distributed with
- * <a href="../index.html">GeographicLib</a> 1.49.
+ * <a href="../index.html">GeographicLib</a> 1.50.
  **********************************************************************/
 
 #if !defined(GEODESIC_H)
@@ -127,7 +127,7 @@
  * The minor version of the geodesic library.  (This tracks the version of
  * GeographicLib.)
  **********************************************************************/
-#define GEODESIC_VERSION_MINOR 49
+#define GEODESIC_VERSION_MINOR 50
 /**
  * The patch level of the geodesic library.  (This tracks the version of
  * GeographicLib.)
@@ -157,6 +157,20 @@
                       GEODESIC_VERSION_MINOR, \
                       GEODESIC_VERSION_PATCH)
 
+#if !defined(GEOD_DLL)
+#if defined(_MSC_VER)
+#define GEOD_DLL __declspec(dllexport)
+#elif defined(__GNUC__)
+#define GEOD_DLL __attribute__ ((visibility("default")))
+#else
+#define GEOD_DLL
+#endif
+#endif
+
+#if defined(PROJ_RENAME_SYMBOLS)
+#include "proj_symbol_rename.h"
+#endif
+
 #if defined(__cplusplus)
 extern "C" {
 #endif
@@ -224,7 +238,7 @@ extern "C" {
    * @param[in] a the equatorial radius (meters).
    * @param[in] f the flattening.
    **********************************************************************/
-  void geod_init(struct geod_geodesic* g, double a, double f);
+  void GEOD_DLL geod_init(struct geod_geodesic* g, double a, double f);
 
   /**
    * Solve the direct geodesic problem.
@@ -262,9 +276,9 @@ extern "C" {
    printf("%.5f %.5f\n", lat, lon);
    @endcode
    **********************************************************************/
-  void geod_direct(const struct geod_geodesic* g,
-                   double lat1, double lon1, double azi1, double s12,
-                   double* plat2, double* plon2, double* pazi2);
+  void GEOD_DLL geod_direct(const struct geod_geodesic* g,
+                            double lat1, double lon1, double azi1, double s12,
+                            double* plat2, double* plon2, double* pazi2);
 
   /**
    * The general direct geodesic problem.
@@ -304,12 +318,13 @@ extern "C" {
    * that the quantity \e lon2 &minus; \e lon1 indicates how many times and in
    * what sense the geodesic encircles the ellipsoid.
    **********************************************************************/
-  double geod_gendirect(const struct geod_geodesic* g,
-                        double lat1, double lon1, double azi1,
-                        unsigned flags, double s12_a12,
-                        double* plat2, double* plon2, double* pazi2,
-                        double* ps12, double* pm12, double* pM12, double* pM21,
-                        double* pS12);
+  double GEOD_DLL geod_gendirect(const struct geod_geodesic* g,
+                                 double lat1, double lon1, double azi1,
+                                 unsigned flags, double s12_a12,
+                                 double* plat2, double* plon2, double* pazi2,
+                                 double* ps12, double* pm12,
+                                 double* pM12, double* pM21,
+                                 double* pS12);
 
   /**
    * Solve the inverse geodesic problem.
@@ -349,9 +364,10 @@ extern "C" {
    printf("%.3f\n", s12);
    @endcode
    **********************************************************************/
-  void geod_inverse(const struct geod_geodesic* g,
-                    double lat1, double lon1, double lat2, double lon2,
-                    double* ps12, double* pazi1, double* pazi2);
+  void GEOD_DLL geod_inverse(const struct geod_geodesic* g,
+                             double lat1, double lon1,
+                             double lat2, double lon2,
+                             double* ps12, double* pazi1, double* pazi2);
 
   /**
    * The general inverse geodesic calculation.
@@ -380,11 +396,12 @@ extern "C" {
    * "return" arguments \e ps12, etc., may be replaced by 0, if you do not need
    * some quantities computed.
    **********************************************************************/
-  double geod_geninverse(const struct geod_geodesic* g,
-                         double lat1, double lon1, double lat2, double lon2,
-                         double* ps12, double* pazi1, double* pazi2,
-                         double* pm12, double* pM12, double* pM21,
-                         double* pS12);
+  double GEOD_DLL geod_geninverse(const struct geod_geodesic* g,
+                                  double lat1, double lon1,
+                                  double lat2, double lon2,
+                                  double* ps12, double* pazi1, double* pazi2,
+                                  double* pm12, double* pM12, double* pM21,
+                                  double* pS12);
 
   /**
    * Initialize a geod_geodesicline object.
@@ -425,9 +442,10 @@ extern "C" {
    * When initialized by this function, point 3 is undefined (l->s13 = l->a13 =
    * NaN).
    **********************************************************************/
-  void geod_lineinit(struct geod_geodesicline* l,
-                     const struct geod_geodesic* g,
-                     double lat1, double lon1, double azi1, unsigned caps);
+  void GEOD_DLL geod_lineinit(struct geod_geodesicline* l,
+                              const struct geod_geodesic* g,
+                              double lat1, double lon1, double azi1,
+                              unsigned caps);
 
   /**
    * Initialize a geod_geodesicline object in terms of the direct geodesic
@@ -450,10 +468,11 @@ extern "C" {
    * 2 of the direct geodesic problem.  See geod_lineinit() for more
    * information.
    **********************************************************************/
-  void geod_directline(struct geod_geodesicline* l,
-                       const struct geod_geodesic* g,
-                       double lat1, double lon1, double azi1, double s12,
-                       unsigned caps);
+  void GEOD_DLL geod_directline(struct geod_geodesicline* l,
+                                const struct geod_geodesic* g,
+                                double lat1, double lon1,
+                                double azi1, double s12,
+                                unsigned caps);
 
   /**
    * Initialize a geod_geodesicline object in terms of the direct geodesic
@@ -480,11 +499,11 @@ extern "C" {
    * 2 of the direct geodesic problem.  See geod_lineinit() for more
    * information.
    **********************************************************************/
-  void geod_gendirectline(struct geod_geodesicline* l,
-                          const struct geod_geodesic* g,
-                          double lat1, double lon1, double azi1,
-                          unsigned flags, double s12_a12,
-                          unsigned caps);
+  void GEOD_DLL geod_gendirectline(struct geod_geodesicline* l,
+                                   const struct geod_geodesic* g,
+                                   double lat1, double lon1, double azi1,
+                                   unsigned flags, double s12_a12,
+                                   unsigned caps);
 
   /**
    * Initialize a geod_geodesicline object in terms of the inverse geodesic
@@ -506,10 +525,11 @@ extern "C" {
    * 2 of the inverse geodesic problem.  See geod_lineinit() for more
    * information.
    **********************************************************************/
-  void geod_inverseline(struct geod_geodesicline* l,
-                       const struct geod_geodesic* g,
-                       double lat1, double lon1, double lat2, double lon2,
-                       unsigned caps);
+  void GEOD_DLL geod_inverseline(struct geod_geodesicline* l,
+                                 const struct geod_geodesic* g,
+                                 double lat1, double lon1,
+                                 double lat2, double lon2,
+                                 unsigned caps);
 
   /**
    * Compute the position along a geod_geodesicline.
@@ -524,9 +544,9 @@ extern "C" {
    * @param[out] pazi2 pointer to the (forward) azimuth at point 2 (degrees).
    *
    * \e l must have been initialized with a call, e.g., to geod_lineinit(),
-   * with \e caps |= GEOD_DISTANCE_IN.  The values of \e lon2 and \e azi2
-   * returned are in the range [&minus;180&deg;, 180&deg;].  Any of the
-   * "return" arguments \e plat2, etc., may be replaced by 0, if you do not
+   * with \e caps |= GEOD_DISTANCE_IN (or \e caps = 0).  The values of \e lon2
+   * and \e azi2 returned are in the range [&minus;180&deg;, 180&deg;].  Any of
+   * the "return" arguments \e plat2, etc., may be replaced by 0, if you do not
    * need some quantities computed.
    *
    * Example, compute way points between JFK and Singapore Changi Airport
@@ -556,8 +576,8 @@ extern "C" {
    }
    @endcode
    **********************************************************************/
-  void geod_position(const struct geod_geodesicline* l, double s12,
-                     double* plat2, double* plon2, double* pazi2);
+  void GEOD_DLL geod_position(const struct geod_geodesicline* l, double s12,
+                              double* plat2, double* plon2, double* pazi2);
 
   /**
    * The general position function.
@@ -623,29 +643,29 @@ extern "C" {
    }
    @endcode
    **********************************************************************/
-  double geod_genposition(const struct geod_geodesicline* l,
-                          unsigned flags, double s12_a12,
-                          double* plat2, double* plon2, double* pazi2,
-                          double* ps12, double* pm12,
-                          double* pM12, double* pM21,
-                          double* pS12);
+  double GEOD_DLL geod_genposition(const struct geod_geodesicline* l,
+                                   unsigned flags, double s12_a12,
+                                   double* plat2, double* plon2, double* pazi2,
+                                   double* ps12, double* pm12,
+                                   double* pM12, double* pM21,
+                                   double* pS12);
 
   /**
    * Specify position of point 3 in terms of distance.
    *
-   * @param[inout] l a pointer to the geod_geodesicline object.
+   * @param[in,out] l a pointer to the geod_geodesicline object.
    * @param[in] s13 the distance from point 1 to point 3 (meters); it
    *   can be negative.
    *
    * This is only useful if the geod_geodesicline object has been constructed
    * with \e caps |= GEOD_DISTANCE_IN.
    **********************************************************************/
-  void geod_setdistance(struct geod_geodesicline* l, double s13);
+  void GEOD_DLL geod_setdistance(struct geod_geodesicline* l, double s13);
 
   /**
    * Specify position of point 3 in terms of either distance or arc length.
    *
-   * @param[inout] l a pointer to the geod_geodesicline object.
+   * @param[in,out] l a pointer to the geod_geodesicline object.
    * @param[in] flags either GEOD_NOFLAGS or GEOD_ARCMODE to determining the
    *   meaning of the \e s13_a13.
    * @param[in] s13_a13 if \e flags = GEOD_NOFLAGS, this is the distance
@@ -657,8 +677,8 @@ extern "C" {
    * GEOD_ARCMODE, the \e s13 is only set if the geod_geodesicline object has
    * been constructed with \e caps |= GEOD_DISTANCE.
    **********************************************************************/
-  void geod_gensetdistance(struct geod_geodesicline* l,
-                           unsigned flags, double s13_a13);
+  void GEOD_DLL geod_gensetdistance(struct geod_geodesicline* l,
+                                    unsigned flags, double s13_a13);
 
   /**
    * Initialize a geod_polygon object.
@@ -679,14 +699,14 @@ extern "C" {
    * An example of the use of this function is given in the documentation for
    * geod_polygon_compute().
    **********************************************************************/
-  void geod_polygon_init(struct geod_polygon* p, int polylinep);
+  void GEOD_DLL geod_polygon_init(struct geod_polygon* p, int polylinep);
 
   /**
    * Clear the polygon, allowing a new polygon to be started.
    *
    * @param[in,out] p a pointer to the object to be cleared.
    **********************************************************************/
-  void geod_polygon_clear(struct geod_polygon* p);
+  void GEOD_DLL geod_polygon_clear(struct geod_polygon* p);
 
   /**
    * Add a point to the polygon or polyline.
@@ -706,9 +726,9 @@ extern "C" {
    * An example of the use of this function is given in the documentation for
    * geod_polygon_compute().
    **********************************************************************/
-  void geod_polygon_addpoint(const struct geod_geodesic* g,
-                             struct geod_polygon* p,
-                             double lat, double lon);
+  void GEOD_DLL geod_polygon_addpoint(const struct geod_geodesic* g,
+                                      struct geod_polygon* p,
+                                      double lat, double lon);
 
   /**
    * Add an edge to the polygon or polyline.
@@ -726,9 +746,9 @@ extern "C" {
    * added yet.  The \e lat and \e lon fields of \e p give the location of the
    * new vertex.
    **********************************************************************/
-  void geod_polygon_addedge(const struct geod_geodesic* g,
-                            struct geod_polygon* p,
-                            double azi, double s);
+  void GEOD_DLL geod_polygon_addedge(const struct geod_geodesic* g,
+                                     struct geod_polygon* p,
+                                     double azi, double s);
 
   /**
    * Return the results for a polygon.
@@ -749,10 +769,12 @@ extern "C" {
    *
    * The area and perimeter are accumulated at two times the standard floating
    * point precision to guard against the loss of accuracy with many-sided
-   * polygons.  Only simple polygons (which are not self-intersecting) are
-   * allowed.  There's no need to "close" the polygon by repeating the first
-   * vertex.  Set \e pA or \e pP to zero, if you do not want the corresponding
-   * quantity returned.
+   * polygons.  Arbitrarily complex polygons are allowed.  In the case of
+   * self-intersecting polygons the area is accumulated "algebraically", e.g.,
+   * the areas of the 2 loops in a figure-8 polygon will partially cancel.
+   * There's no need to "close" the polygon by repeating the first vertex.  Set
+   * \e pA or \e pP to zero, if you do not want the corresponding quantity
+   * returned.
    *
    * More points can be added to the polygon after this call.
    *
@@ -773,10 +795,10 @@ extern "C" {
    printf("%d %.8f %.3f\n", n, P, A);
    @endcode
    **********************************************************************/
-  unsigned geod_polygon_compute(const struct geod_geodesic* g,
-                                const struct geod_polygon* p,
-                                int reverse, int sign,
-                                double* pA, double* pP);
+  unsigned GEOD_DLL geod_polygon_compute(const struct geod_geodesic* g,
+                                         const struct geod_polygon* p,
+                                         int reverse, int sign,
+                                         double* pA, double* pP);
 
   /**
    * Return the results assuming a tentative final test point is added;
@@ -804,11 +826,11 @@ extern "C" {
    *
    * \e lat should be in the range [&minus;90&deg;, 90&deg;].
    **********************************************************************/
-  unsigned geod_polygon_testpoint(const struct geod_geodesic* g,
-                                  const struct geod_polygon* p,
-                                  double lat, double lon,
-                                  int reverse, int sign,
-                                  double* pA, double* pP);
+  unsigned GEOD_DLL geod_polygon_testpoint(const struct geod_geodesic* g,
+                                           const struct geod_polygon* p,
+                                           double lat, double lon,
+                                           int reverse, int sign,
+                                           double* pA, double* pP);
 
   /**
    * Return the results assuming a tentative final test point is added via an
@@ -835,11 +857,11 @@ extern "C" {
    *   polyline (meters).
    * @return the number of points.
    **********************************************************************/
-  unsigned geod_polygon_testedge(const struct geod_geodesic* g,
-                                 const struct geod_polygon* p,
-                                 double azi, double s,
-                                 int reverse, int sign,
-                                 double* pA, double* pP);
+  unsigned GEOD_DLL geod_polygon_testedge(const struct geod_geodesic* g,
+                                          const struct geod_polygon* p,
+                                          double azi, double s,
+                                          int reverse, int sign,
+                                          double* pA, double* pP);
 
   /**
    * A simple interface for computing the area of a geodesic polygon.
@@ -854,10 +876,11 @@ extern "C" {
    *
    * \e lats should be in the range [&minus;90&deg;, 90&deg;].
    *
-   * Only simple polygons (which are not self-intersecting) are allowed.
-   * There's no need to "close" the polygon by repeating the first vertex.  The
-   * area returned is signed with counter-clockwise traversal being treated as
-   * positive.
+   * Arbitrarily complex polygons are allowed.  In the case self-intersecting
+   * of polygons the area is accumulated "algebraically", e.g., the areas of
+   * the 2 loops in a figure-8 polygon will partially cancel.  There's no need
+   * to "close" the polygon by repeating the first vertex.  The area returned
+   * is signed with counter-clockwise traversal being treated as positive.
    *
    * Example, compute the area of Antarctica:
    @code{.c}
@@ -873,9 +896,9 @@ extern "C" {
    printf("%.0f %.2f\n", A, P);
    @endcode
    **********************************************************************/
-  void geod_polygonarea(const struct geod_geodesic* g,
-                        double lats[], double lons[], int n,
-                        double* pA, double* pP);
+  void GEOD_DLL geod_polygonarea(const struct geod_geodesic* g,
+                                 double lats[], double lons[], int n,
+                                 double* pA, double* pP);
 
   /**
    * mask values for the \e caps argument to geod_lineinit().
