@@ -66,7 +66,7 @@ function [lat2, lon2, azi2, S12, m12, M12, M21, a12_s12] = geodreckon ...
 %
 %   See also GEODDOC, GEODDISTANCE, GEODAREA, DEFAULTELLIPSOID, FLAT2ECC.
 
-% Copyright (c) Charles Karney (2012-2017) <charles@karney.com>.
+% Copyright (c) Charles Karney (2012-2018) <charles@karney.com>.
 %
 % This is a straightforward transcription of the C++ implementation in
 % GeographicLib and the C++ source should be consulted for additional
@@ -244,7 +244,8 @@ function [lat2, lon2, azi2, S12, m12, M12, M21, a12_s12] = geodreckon ...
     B42 = SinCosSeries(false, ssig2, csig2, C4a);
     salp12 = calp0 .* salp0 .* ...
              cvmgt(csig1 .* (1 - csig12) + ssig12 .* ssig1, ...
-                   ssig12 .* (csig1 .* ssig12 ./ (1 + csig12) + ssig1), ...
+                   ssig12 .* ...
+                   (csig1 .* ssig12 ./ max(1, (1 + csig12)) + ssig1), ...
                    csig12 <= 0);
     calp12 = salp0.^2 + calp0.^2 .* csig1 .* csig2;
     % Deal with geodreckon(10, 0, [], 0) which has calp2 = []
