@@ -2,7 +2,7 @@
  * \file DMS.cpp
  * \brief Implementation for GeographicLib::DMS class
  *
- * Copyright (c) Charles Karney (2008-2017) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2008-2019) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  **********************************************************************/
@@ -27,19 +27,23 @@ namespace GeographicLib {
 
   Math::real DMS::Decode(const std::string& dms, flag& ind) {
     string dmsa = dms;
+    replace(dmsa, "\xe2\x88\x92", '-');  // U+2212 minus sign
     replace(dmsa, "\xc2\xb0", 'd');      // U+00b0 degree symbol
+    replace(dmsa, "\xb0", 'd');          // 0xb0 bare degree symbol
     replace(dmsa, "\xc2\xba", 'd');      // U+00ba alt symbol
+    replace(dmsa, "\xba", 'd');          // 0xba bare alt symbol
     replace(dmsa, "\xe2\x81\xb0", 'd');  // U+2070 sup zero
     replace(dmsa, "\xcb\x9a", 'd');      // U+02da ring above
     replace(dmsa, "\xe2\x80\xb2", '\''); // U+2032 prime
     replace(dmsa, "\xc2\xb4", '\'');     // U+00b4 acute accent
+    replace(dmsa, "\xb4", '\'');         // 0xb4 bare acute accent
     replace(dmsa, "\xe2\x80\x99", '\''); // U+2019 right single quote
     replace(dmsa, "\xe2\x80\xb3", '"');  // U+2033 double prime
     replace(dmsa, "\xe2\x80\x9d", '"');  // U+201d right double quote
-    replace(dmsa, "\xe2\x88\x92", '-');  // U+2212 minus sign
-    replace(dmsa, "\xb0", 'd');          // 0xb0 bare degree symbol
-    replace(dmsa, "\xba", 'd');          // 0xba bare alt symbol
-    replace(dmsa, "\xb4", '\'');         // 0xb4 bare acute accent
+    replace(dmsa, "\xc2\xa0", '\0');     // U+00a0 non-breaking space
+    replace(dmsa, "\xa0", '\0');         // 0xa0 bare non-breaking space
+    replace(dmsa, "\xe2\x80\xaf", '\0'); // U+202f narrow space
+    replace(dmsa, "\xe2\x80\x87", '\0'); // U+2007 figure space
     replace(dmsa, "''", '"');            // '' -> "
     string::size_type
       beg = 0,
