@@ -2,7 +2,7 @@
  * \file Geodesic.cpp
  * \brief Implementation for GeographicLib::Geodesic class
  *
- * Copyright (c) Charles Karney (2009-2017) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2009-2019) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  *
@@ -183,7 +183,7 @@ namespace GeographicLib {
     // If really close to the equator, treat as on equator.
     lat1 = Math::AngRound(Math::LatFix(lat1));
     lat2 = Math::AngRound(Math::LatFix(lat2));
-    // Swap points so that point with higher (abs) latitude is point 1
+    // Swap points so that point with higher (abs) latitude is point 1.
     // If one latitude is a nan, then it becomes lat1.
     int swapp = abs(lat1) < abs(lat2) ? -1 : 1;
     if (swapp < 0) {
@@ -654,23 +654,7 @@ namespace GeographicLib {
       // bet12 = bet2 - bet1 in [0, pi); bet12a = bet2 + bet1 in (-pi, 0]
       sbet12 = sbet2 * cbet1 - cbet2 * sbet1,
       cbet12 = cbet2 * cbet1 + sbet2 * sbet1;
-#if defined(__GNUC__) && __GNUC__ == 4 && \
-  (__GNUC_MINOR__ < 6 || defined(__MINGW32__))
-    // Volatile declaration needed to fix inverse cases
-    // 88.202499451857 0 -88.202499451857 179.981022032992859592
-    // 89.262080389218 0 -89.262080389218 179.992207982775375662
-    // 89.333123580033 0 -89.333123580032997687 179.99295812360148422
-    // which otherwise fail with g++ 4.4.4 x86 -O3 (Linux)
-    // and g++ 4.4.0 (mingw) and g++ 4.6.1 (tdm mingw).
-    real sbet12a;
-    {
-      GEOGRAPHICLIB_VOLATILE real xx1 = sbet2 * cbet1;
-      GEOGRAPHICLIB_VOLATILE real xx2 = cbet2 * sbet1;
-      sbet12a = xx1 + xx2;
-    }
-#else
     real sbet12a = sbet2 * cbet1 + cbet2 * sbet1;
-#endif
     bool shortline = cbet12 >= 0 && sbet12 < real(0.5) &&
       cbet2 * lam12 < real(0.5);
     real somg12, comg12;
