@@ -22,7 +22,7 @@
 #endif
 
 #if !defined(GEOGRAPHICLIB_MAGNETIC_DEFAULT_NAME)
-#  define GEOGRAPHICLIB_MAGNETIC_DEFAULT_NAME "wmm2015v2"
+#  define GEOGRAPHICLIB_MAGNETIC_DEFAULT_NAME "wmm2020"
 #endif
 
 #if defined(_MSC_VER)
