@@ -2,7 +2,7 @@
  * \file TransverseMercatorExact.cpp
  * \brief Implementation for GeographicLib::TransverseMercatorExact class
  *
- * Copyright (c) Charles Karney (2008-2016) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2008-2017) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  *
@@ -95,8 +95,8 @@ namespace GeographicLib {
     real
       d1 = sqrt(Math::sq(cnu) + _mv * Math::sq(snu * snv)),
       d2 = sqrt(_mu * Math::sq(cnu) + _mv * Math::sq(cnv)),
-      t1 = (d1 ? snu * dnv / d1 : (snu < 0 ? -overflow : overflow)),
-      t2 = (d2 ? sinh( _e * Math::asinh(_e * snu / d2) ) :
+      t1 = (d1 != 0 ? snu * dnv / d1 : (snu < 0 ? -overflow : overflow)),
+      t2 = (d2 != 0 ? sinh( _e * Math::asinh(_e * snu / d2) ) :
             (snu < 0 ? -overflow : overflow));
     // psi = asinh(t1) - asinh(t2)
     // taup = sinh(psi)
@@ -119,8 +119,8 @@ namespace GeographicLib {
   }
 
   // Starting point for zetainv
-  bool TransverseMercatorExact::zetainv0(real psi, real lam, real& u, real& v)
-    const {
+  bool TransverseMercatorExact::zetainv0(real psi, real lam,
+                                         real& u, real& v) const {
     bool retval = false;
     if (psi < -_e * Math::pi()/4 &&
         lam > (1 - 2 * _e) * Math::pi()/2 &&
@@ -184,8 +184,8 @@ namespace GeographicLib {
   }
 
   // Invert zeta using Newton's method
-  void TransverseMercatorExact::zetainv(real taup, real lam, real& u, real& v)
-    const  {
+  void TransverseMercatorExact::zetainv(real taup, real lam,
+                                        real& u, real& v) const  {
     real
       psi = Math::asinh(taup),
       scal = 1/Math::hypot(real(1), taup);
@@ -242,8 +242,8 @@ namespace GeographicLib {
   }
 
   // Starting point for sigmainv
-  bool TransverseMercatorExact::sigmainv0(real xi, real eta, real& u, real& v)
-    const {
+  bool TransverseMercatorExact::sigmainv0(real xi, real eta,
+                                          real& u, real& v) const {
     bool retval = false;
     if (eta > real(1.25) * _Ev.KE() ||
         (xi < -real(0.25) * _Eu.E() && xi < eta - _Ev.KE())) {
@@ -292,8 +292,8 @@ namespace GeographicLib {
   }
 
   // Invert sigma using Newton's method
-  void TransverseMercatorExact::sigmainv(real xi, real eta, real& u, real& v)
-    const {
+  void TransverseMercatorExact::sigmainv(real xi, real eta,
+                                         real& u, real& v) const {
     if (sigmainv0(xi, eta, u, v))
       return;
     // min iterations = 2, max iterations = 7; mean = 3.9
@@ -346,8 +346,8 @@ namespace GeographicLib {
   }
 
   void TransverseMercatorExact::Forward(real lon0, real lat, real lon,
-                                        real& x, real& y, real& gamma, real& k)
-    const {
+                                        real& x, real& y,
+                                        real& gamma, real& k) const {
     lat = Math::LatFix(lat);
     lon = Math::AngDiff(lon0, lon);
     // Explicitly enforce the parity
@@ -407,8 +407,7 @@ namespace GeographicLib {
 
   void TransverseMercatorExact::Reverse(real lon0, real x, real y,
                                         real& lat, real& lon,
-                                        real& gamma, real& k)
-    const {
+                                        real& gamma, real& k) const {
     // This undoes the steps in Forward.
     real
       xi = y / (_a * _k0),
