@@ -2,7 +2,7 @@
  * \file Gravity.cpp
  * \brief Command line utility for evaluating gravity fields
  *
- * Copyright (c) Charles Karney (2011-2017) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2011-2019) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  *
@@ -38,7 +38,7 @@ int main(int argc, const char* const argv[]) {
     char lsep = ';';
     real lat = 0, h = 0;
     bool circle = false;
-    int prec = -1;
+    int prec = -1, Nmax = -1, Mmax = -1;
     enum {
       GRAVITY = 0,
       DISTURBANCE = 1,
@@ -54,6 +54,32 @@ int main(int argc, const char* const argv[]) {
       } else if (arg == "-d") {
         if (++m == argc) return usage(1, true);
         dir = argv[m];
+      } else if (arg == "-N") {
+        if (++m == argc) return usage(1, true);
+        try {
+          Nmax = Utility::val<int>(std::string(argv[m]));
+          if (Nmax < 0) {
+            std::cerr << "Maximum degree " << argv[m] << " is negative\n";
+            return 1;
+          }
+        }
+        catch (const std::exception&) {
+          std::cerr << "Precision " << argv[m] << " is not a number\n";
+          return 1;
+        }
+      } else if (arg == "-M") {
+        if (++m == argc) return usage(1, true);
+        try {
+          Mmax = Utility::val<int>(std::string(argv[m]));
+          if (Mmax < 0) {
+            std::cerr << "Maximum order " << argv[m] << " is negative\n";
+            return 1;
+          }
+        }
+        catch (const std::exception&) {
+          std::cerr << "Precision " << argv[m] << " is not a number\n";
+          return 1;
+        }
       } else if (arg == "-G")
         mode = GRAVITY;
       else if (arg == "-D")
@@ -180,7 +206,7 @@ int main(int argc, const char* const argv[]) {
     }
     int retval = 0;
     try {
-      const GravityModel g(model, dir);
+      const GravityModel g(model, dir, Nmax, Mmax);
       if (circle) {
         if (!Math::isfinite(h))
           throw GeographicErr("Bad height");
@@ -267,7 +293,7 @@ int main(int argc, const char* const argv[]) {
                 c.SphericalAnomaly(lon, Dg01, xi, eta);
               else
                 g.SphericalAnomaly(lat, lon, h, Dg01, xi, eta);
-              Dg01 *= 100000;      // Convert to mGals
+              Dg01 *= 100000;   // Convert to mGals
               xi *= 3600;       // Convert to arcsecs
               eta *= 3600;
               *output << Utility::str(Dg01, prec) << " "
