@@ -4,7 +4,7 @@
 # modeled on a similar script geographiclib-datasets-download by
 # Francesco P. Lovergine <frankie@debian.org>
 #
-# Copyright (c) Charles Karney (2011-2013) <charles@karney.com> and
+# Copyright (c) Charles Karney (2011-2019) <charles@karney.com> and
 # licensed under the MIT/X11 License.  For more information, see
 # https://geographiclib.sourceforge.io/
 
@@ -17,7 +17,7 @@ TOOL=GeoidEval
 EXT=pgm
 usage() {
     cat <<EOF
-usage: $0 [-p parentdir] [-d] [-h] $MODEL...
+usage: $0 [-p parentdir] [-f] [-d] [-h] $MODEL...
 
 This program downloads and installs the datasets used by the
 GeographicLib::$CLASS class and the $TOOL tool to compute geoid
@@ -55,6 +55,8 @@ write access to this directory.
 
 Normally only datasets which are not already in parentdir are
 downloaded.  You can force the download and reinstallation with -f.
+The -f flag also let you download new models (not yet in the set
+defined by "all").
 
 If -d is provided, the temporary directory which holds the downloads,
 \$TMPDIR/$NAME-XXXXXXXX or ${TMPDIR:-/tmp}/$NAME-XXXXXXXX,
@@ -158,8 +160,12 @@ egm84-15
 EOF
 		;;
 	    * )
-		echo Unknown $MODEL $1 1>&2
-		exit 1
+		if test -n "$FORCE"; then
+		    echo $1
+		else
+		    echo Unknown $MODEL $1 1>&2
+		    exit 1
+		fi
 		;;
 	esac
     fi
